//课程表
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQuery,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import classScheduleApi from "../api/classScheduleApi";
import { request } from "../globalConfiguration";
//课程表接口
const PagesData = {
  semesterName: undefined,
  weekType: undefined,
  weekStart: undefined,
  weekEnd: undefined,
  classWeek: undefined,
  lessonSetDetailIds: undefined,
  classId: undefined,
  classBuildingId: undefined,
  teacherId: undefined,
  courseId: undefined,
  className: undefined,
  classBuildingName: undefined,
  teacherName: undefined,
  courseName: undefined,
};
/**
 * @Post 请求
 *添加课程表
 * @param {data} 参数
 * {semesterId} 学期Id  *
 * {weekType} 周类型 *
 * {weekStart} 起始周 *
 * {weekEnd} 截止周 *
 * {classWeek}  上课星期 *
 * {lessonSetDetailIds}  上课节数 *
 * {classId}  教室Id *
 * {classBuildingId}  教学班Id （上课班级）*
 * {teacherId}  授课老师Id *
 * {courseId}  课程Id *
 * {courseName} 课程名称
 * {classSchNumber} 教室编号
 * {teacherName} 授课老师名称
 * @param {config} 配置项
 * @returns
 */
function classScheduleAdd(data = PagesData, config = {}) {
  return request(
    submit(
      {
        fkXqId: data.semesterId || undefined, //学期id
        jsbh:data.classSchNumber||undefined,//教室编号
        jxbxx :data.shollId||undefined,//所属学校id
        jxbxxid:data.shollName||undefined,//所属学校名称
        zlx: data.weekType || undefined, //周类型
        qsz: data.weekStart || undefined, //起始周
        jzz: data.weekEnd || undefined, //截止周
        skxq: data.classWeek || undefined, //上课星期
        lessonSetDetailIds: data.lessonSetDetailIds || undefined, //上课节数
        fkJsId: data.classId || undefined, //教室Id
        fkJxbId: data.classBuildingId || undefined, //教学班Id
        sklsid: data.teacherId || undefined, //授课老师Id
        skls:data.teacherName||undefined,//授课老师名称
        kcid: data.courseId || undefined, // 课程Id
        kcmc:data.courseName|| undefined, // 课程名称
      },
      classScheduleApi.classScheduleAdd,
      config
    )
  );
}

/**
 * @Post 请求
 *更新课程表
 * @param {data} 参数
 * {semesterId} 学期Id  *
 * {weekType} 周类型 *
 * {weekStart} 起始周 *
 * {weekEnd} 截止周 *
 * {classWeek}  上课星期 *
 * {lessonSetDetailIds}  上课节数 *
 * {classId}  教室Id *
 * {classBuildingId}  教学班Id （上课班级）*
 * {teacherId}  授课老师Id *
 * {courseId}  课程Id *
 * {courseName} 课程名称
 * {classSchNumber} 教室编号
 * {teacherName} 授课老师名称
 * @param {config} 配置项
 * @returns
 */
function classScheduleUpdate(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id:data.id||undefined,
        fkXqId: data.semesterId || undefined, //学期id
        jsbh:data.classSchNumber||undefined,//教室编号
        jxbxx :data.shollId||undefined,//所属学校id
        jxbxxid:data.shollName||undefined,//所属学校名称
        zlx: data.weekType || undefined, //周类型
        qsz: data.weekStart || undefined, //起始周
        jzz: data.weekEnd || undefined, //截止周
        skxq: data.classWeek || undefined, //上课星期
        lessonSetDetailIds: data.lessonSetDetailIds || undefined, //上课节数
        fkJsId: data.classId || undefined, //教室Id
        fkJxbId: data.classBuildingId || undefined, //教学班Id
        sklsid: data.teacherId || undefined, //授课老师Id
        skls:data.teacherName||undefined,//授课老师名称
        kcid: data.courseId || undefined, // 课程Id
        kcmc:data.courseName|| undefined, // 课程名称
      },
      classScheduleApi.classScheduleUpdate,
      config
    )
  );
}

/**
 * @DELETE 请求
 *批量删除课程表
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function classScheduleDel(data, config = {}) {
  return request(
    batchDeletion(data, classScheduleApi.classScheduleDel, config)
  );
}

/**
 * @Get 请求
 *根据课程表id和第几周获取课程表详情
 * {semesterName} 课程表名称
 * {lecturePeriod} 节课时长
 * {weekOfSemester}本课程表第几周
 * {sectionDay}日节课数
 * {weekList} 星期列表
 * {weekNumber} 星期几
 * {correspondingDate} 对应日期
 * {sectionContent}节课内容
 * {associatSectionId}关联节课配置Id
 * {classStartTime}上课时间
 * {classEndTime}下课时间
 * @param {data} 参数
 * {schoolId} 学校id
 * {week} 第几周
 * {xqId} 学期id
 * @param {config} 配置项
 * @returns
 */
function getScheduleByIdAndWeek(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      singleQuery(data, classScheduleApi.getScheduleByIdAndWeek, config)
    ).then(({ result }) => {
      resolve({
        id: result.fkXqId || undefined, //学期Id
        semesterName: result.xqmc || undefined, //学期名称
        lecturePeriod: result.jksc || undefined, //节课时长
        weekOfSemester: result.weekOfSemester || undefined, //本学期第几周
        sectionDay: result.rjks || undefined, //日节课数
        weekList:
          result.rows.length > 0
            ? result.rows.map((item) => ({
                weekId: item.week || undefined, //星期几Id
                weekNumber: item.name || undefined, //星期几
                correspondingDate: item.dayOfYear || undefined, //对应日期
              }))
            : [],
        sectionContent:
          result.columns.length > 0
            ? result.columns.map((item) => ({
                id: item.id || undefined, //节课Id
                idx: item.idx || undefined, //第几节Id
                associatSectionId: item.fkJkpzId || undefined, //关联节课配置
                classStartTime: item.sksj || undefined, //上课时间
                classEndTime: item.xksj || undefined, //下课时间
              }))
            : [],
      });
    });
  });
}
/**
 *查询课程表列表
 * @Post 请求
 * @param {data} 参数
 * {classroomIds}  教室Ids 数组*
 * {keyword}  关键字查询 *
 * {teacherId}  授课老师Id *
 * {courseIds}  课程Ids 数组*
 * {semesters}  学期 数组*
 * {dateClass} 上课星期（1-7）集合 数组 *
 *
 * @param {config} 配置项
 * @returns
 */
function classScheduleList(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          id: data.id || undefined,
          jsIds: data.classroomIds || undefined, //教室ids 数组
          kcIds: data.courseIds || undefined, //课程ids 数组
          keyword: data.keyword || undefined, //关键字查询
          lsIds: data.teacherId || undefined, //老师ids 数组
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
          skxqs: data.dateClass || undefined,
          xnxqIds: data.semesters || undefined,
        },
        classScheduleApi.classScheduleList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          id: item.id || undefined,
          semesterName: item.xqmc || undefined,//学期名称
          classWeek: item.skxq || undefined,//上课星期
          lessonSetDetailIds: item.lessonSetDetailIds || undefined,//节课id数组
          lessons:item.lessons||undefined,//节课名称
          classroomName: item.jsmc || undefined,//教室名称
          classroomId:item.fkJsId||undefined,//教室id
          classBuildingName: item.jxbmc || undefined,//教学班名称
          classBuildingId:item.fkJxbId|| undefined,//教学班id
          teacherName: item.skls || undefined,//授课老师名称
          teacherid:item.sklsid||undefined,//授课老师id
          courseName: item.kcmc || undefined,//授课课程名称
          shollName:item.jsxx||undefined,//校区名称
          semesterId:item.fkXqId||undefined,//学期id
          weekType:item.zlx||undefined,//周类型
          weekStart:item.qsz||undefined,//起始周
          weekEnd:item.jzz||undefined,//截止周
        }))
      );
    });
  });
}
/**
 *分页查询
 * @param {data} 参数
 * {classroomIds}  教室Ids 数组*
 * {keyword}  关键字查询 *
 * {teacherId}  授课老师Id *
 * {courseIds}  课程Ids 数组*
 * {semesters}  学期 数组*
 * {dateClass} 上课星期（1-7）集合 数组 *
 * @param {config} 配置项
 * @returns
 */
function listPagesClassSchedule(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          id: data.id || undefined,
          jsIds: data.classroomIds || undefined, //教室ids 数组
          kcIds: data.courseIds || undefined, //课程ids 数组
          keyword: data.keyword || undefined, //关键字查询
          lsIds: data.teacherId || undefined, //老师ids 数组
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
          skxqs: data.dateClass || undefined,
          xnxqIds: data.semesters || undefined,
        },
        classScheduleApi.listPagesClassSchedule,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  semesterName: item.xqmc || undefined,//学期名称
                  classWeek: item.skxq || undefined,//上课星期
                  lessonSetDetailIds: item.lessonSetDetailIds || undefined,//节课id数组
                  lessons:item.lessons||undefined,//节课名称
                  classroomName: item.jsmc || undefined,//教室名称
                  classroomId:item.fkJsId||undefined,//教室id
                  classBuildingName: item.jxbmc || undefined,//教学班名称
                  classBuildingId:item.fkJxbId|| undefined,//教学班id
                  teacherName: item.skls || undefined,//授课老师名称
                  teacherid:item.sklsid||undefined,//授课老师id
                  courseName: item.kcmc || undefined,//授课课程名称
                  shollName:item.jsxx||undefined,//校区名称
                  semesterId:item.fkXqId||undefined,//学期id
                  weekType:item.zlx||undefined,//周类型
                  weekStart:item.qsz||undefined,//起始周
                  weekEnd:item.jzz||undefined,//截止周

                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}
export {
  classScheduleAdd,
  classScheduleUpdate,
  classScheduleDel,
  getScheduleByIdAndWeek,
  classScheduleList,
  listPagesClassSchedule,
};
